// Example.cpp : Defines the initialization routines for the DLL.
//

#include "stdafx.h"

#include "OptPlugin.h"
#include "PluginPropertiesDlg.h"
#include "resource.h"

extern "C" int APIENTRY
DllMain(HINSTANCE hInstance, DWORD dwReason, LPVOID lpReserved)
{
	// Remove this if you use lpReserved
	UNREFERENCED_PARAMETER(lpReserved);

	return 1;
}

class CExample : public OptimusMiniPlugin
{
	// the plug-in properties
	int m_nR, m_nG, m_nB;

	// our plug-in is static, thus we paint only on activation and properties change
	bool m_bPaintRequired;

public:

	CExample( int function )
	{
		m_nR = m_nG = m_nB = 128;
	}

	BOOL __stdcall Paint(HDC hdc)
	{
		if( m_bPaintRequired )
		{
			m_bPaintRequired = FALSE;

			// some paint code using plug-in settings
			RECT rect = { 0,0, IMG_X_SIZE -1, IMG_Y_SIZE -1 };
			HBRUSH color = ::CreateSolidBrush( RGB(m_nR, m_nG, m_nB) );
			::FillRect( hdc, &rect, color );
			::DeleteObject( color ); // Don't forget to free GDI objects

			return TRUE;
		}

		return FALSE;
	}

	void __stdcall OnKeyDown()
	{
		// some action
		Beep(1000,100);
	}

	LPARAM __stdcall GetInfo(int index)
	{
		GET_INFO( INFO_KEY, "example.mfc5" );
		GET_INFO( INFO_NAME, "Example" );
		GET_INFO( INFO_DESC, "My first plug-in example" );

		GET_INFO( INFO_AUTHOR, "Author Name" );
		GET_INFO( INFO_EMAIL, "author@email.com" );
		GET_INFO( INFO_HOMEPAGE, "http://author.url.com" );

		GET_ICON_EX("BIG_ICON");		
		GET_INFO( INFO_HAS_PROPERTIES, 1 );
		GET_IMAGE( INFO_DEFIMAGE, MAKEINTRESOURCE(IDB_DEFIMAGE) );

		return 0;
	}

	BOOL __stdcall GetProperty(int index, char *name, char *value)
	{
		GET_INT_PROPERTY( 0, "R", m_nR );
		GET_INT_PROPERTY( 1, "G", m_nG );
		GET_INT_PROPERTY( 2, "B", m_nB );
		return FALSE;
	}

	BOOL __stdcall SetProperty(const char *name, const char *value)
	{
		SET_INT_PROPERTY( "R", m_nR );
		SET_INT_PROPERTY( "G", m_nG );
		SET_INT_PROPERTY( "B", m_nB );
		return FALSE;
	}

	BOOL __stdcall ShowProperties(HWND hwnd)
	{
		CPluginPropertiesDlg dlg;

		// setting dialog data
		dlg.m_nR = m_nR*100/255;
		dlg.m_nG = m_nG*100/255;
		dlg.m_nB = m_nB*100/255;

		if( dlg.DoModal() == IDOK )
		{
			// setting plug-in data only if IDOK
			m_nR = dlg.m_nR*255/100;
			m_nG = dlg.m_nG*255/100;
			m_nB = dlg.m_nB*255/100;

			m_bPaintRequired = true;
			return TRUE;
		}

		return FALSE;
	}

	BOOL __stdcall OnEvent(int event)
	{ 
		switch (event)
		{
		case EVENT_ACTIVATE:
			{
				// allocate resources
				m_bPaintRequired = true; 
				break;
			}
		case EVENT_DEACTIVATE:
			{
				// deallocate resources
			}
		}
		return TRUE; 
	}
};

PLUGIN_EXPORT(CExample)
